@@ -189,7 +189,7 @@ class _FinXClient:
                 self.__dict__[f'{batch}{name}'] = types.MethodType(locals()[f'{batch}{name}'], self)
 
     def _download_file(self, file_result):
-        url, params = self.__api_url + f'{("api" not in self.__api_url and "api/") or ""}batch-download/', {
+        url, params = self.__api_url + f'{("api/" not in self.__api_url and "api/") or ""}batch-download/', {
             'filename': file_result['filename'],
             'bucket_name': file_result.get('bucket_name')}
         print(url, params)
@@ -219,7 +219,7 @@ class _FinXClient:
             print('Found in cache')
             return cached_response
         async with SessionManager() as session:
-            data = await session.fetch(self.__api_url, **request_body)
+            data = await session.fetch(self.__api_url + f'{("api/" not in self.__api_url and "api/") or ""}', **request_body)
             error = data.get('error')
             if error is not None:
                 print(f'API returned error: {error}')
@@ -433,7 +433,7 @@ class _SocketFinXClient(_FinXClient):
         outstanding_requests = batch_input_df.loc[batch_input_df['cached_responses'].isnull()]
         return cache_keys, cached_responses, outstanding_requests.to_dict(orient='records')
 
-    def _upload_batch_file(self, batch_input):
+    def upload_batch_file(self, batch_input):
         """
         Send batch input file to server for later retrieval in dispatch on server side
         """
@@ -456,8 +456,9 @@ class _SocketFinXClient(_FinXClient):
                 with open(filename, 'w+') as file:
                     file.write('\n'.join(batch_input))
         file = open(filename, 'rb')
+        print('URL ', self.__api_url + f'{("api" not in self.__api_url and "api/") or ""}batch-upload/')
         response = requests.post(  # Upload file to server and record filename
-            self.__api_url + 'batch-upload/',
+            self.__api_url + f'{("api/" not in self.__api_url and "api/") or ""}batch-upload/',
             data={'finx_api_key': self.__api_key, 'filename': filename},
             files={'file': file})
         try:
